/**
 * This script applies Yadif to all media in the project, which 
 * still doesn't have FieldOrder set to Progressive
 *
 **/

using Sony.Vegas;
using System;


public class EntryPoint 
{

    Effect CreateFX(Vegas vegas, String plugInName)  
    {
        PlugInNode plugIn = vegas.VideoFX.GetChildByName(plugInName);

        if (null == plugIn)
            throw new ApplicationException(String.Format("Failed to find plug-in: '{0}'", plugInName));

        return new Effect(plugIn);
    }

    public void FromVegas(Vegas vegas) 
    {
        VideoFieldOrder targetFieldOrder = VideoFieldOrder.ProgressiveScan;

        foreach (Media media in vegas.Project.MediaPool) 
        {
            if (media.HasVideo()) 
            {
                VideoStream videoStream = (VideoStream) media.Streams.GetItemByMediaType(MediaType.Video, 0);
                
                if (videoStream.FieldOrder != VideoFieldOrder.ProgressiveScan)
                {
                    videoStream.FieldOrder = VideoFieldOrder.ProgressiveScan;

                    Effect yadif = CreateFX(vegas,"Yadif Deinterlace");

                    media.Effects.Insert(0,yadif);
                }
            }
        }
    }
}
